Module context

Module context 

Variable expansion and assignment contexts used in Condition evalulation.

Designed as a subset of official RewriteCond back-references.

Structs

DateCtx
All variables and references associated with TIME_ prefix.
EngineCtx
Global Context used for variable replacement in Condition expressions.
EnvCtx
Environment Variable Context.
RequestCtx
All variables and references associated with REMOTE_ prefix and other request variables.
ServerCtx
All variables and references associated with SERVER_ prefix and other server attributes.

Traits

ContextProvider
Abstraction for RewriteCond variable providers