Struct EngineCtx

pub struct EngineCtx<'a>(/* private fields */);
Global Context used for variable replacement in Condition expressions.

Implementations

Source

impl<'a> EngineCtx<'a>

pub fn push_ctx(&mut self, ctx: impl ContextProvider + 'a) -> &mut Self

Assign new sub-context to the complete EngineCtx

pub fn with_ctx(self, ctx: impl ContextProvider + 'a) -> Self

Assign new sub-context when building EngineCtx

pub fn with_env(self) -> Self

Add EnvCtx when building EngineCtx

pub fn with_time(self) -> Self

Add DateCtx when building EngineCtx

pub fn fill(&mut self, expr: &str) -> &str

Return the equivalent value associated with the specified variable expression.

pub fn replace_all(&mut self, expr: &str) -> String

Replace all variables within expression with data specified within with the EngineCtx and return the updated string.