pub struct Condition { /* private fields */ }Expand description
Singular RewriteCond expression definition.
It contains an expression matcher and additional flags that define how the rule behaves within the rule-engine.
Supports a subset of offical mod_rewrite rules.
Implementations